@@ -667,6 +667,6 @@ WHERE
             KG__security_event__event_lock: reg_env_ins[KG__security_event__event_lock]
         }
 
-    def submit(self, inputs: dict, account_id: str, verification_hook: Queue = None):
+    def submit(self, inputs: dict, account_id: str, verification_hook: Queue = None, as_objects: bool = False, singleton: bool = False):
         return submit(self.vault, self.config, self.get_db_crypt_key(), self.jaaql_lookup_connection, inputs, account_id, verification_hook,
-                      self.cached_canned_query_service)
+                      self.cached_canned_query_service, as_objects=as_objects, singleton=singleton)
